@@ -520,10 +520,10 @@ class BibConfig(wx.Config):
 			f = file( os.path.join(wx.StandardPaths.Get().GetUserDataDir(), "Shortcuts", shortname), 'r' )
 			short = cPickle.load(f)		# we unpickle the file then check that it is a list of strings
 			f.close()
-			if type(short) != list: raise "notalist"
+			if type(short) != list: raise TypeError('notalist')
 			else:
 				for i in short:
-					if type(i) not in (unicode,str): raise "notastring"
+					if type(i) not in (unicode,str): raise TypeError('notastring')
 		except:
 			short = []
 		BIB.SHORT[ shortname ] = short
