@@ -26,11 +26,14 @@
 # JournalTitle, MedAbbr, IsoAbbr
 
 # usage:
-# >> parsePubMedJ.py J_Entrez > journals
+# >> parsePubMedJ.py J_Entrez > journals.csv
 # or
-# cat cat J_Entrez | parsePubMedJ.py > journals
+# cat cat J_Entrez | parsePubMedJ.py > journals.csv
 
-import fileinput,cPickle,sys
+import fileinput,csv,sys
+from title_case import title_case
+
+output = csv.writer(sys.stdout)
 journal = {}
 
 tmpj = {}
@@ -40,8 +43,7 @@ for line in fileinput.input():
 		if ls[0] == 'JrId' and tmpj and (tmpj['MedAbbr'] or tmpj['IsoAbbr']):
 			if tmpj['MedAbbr']=="":
 					tmpj['MedAbbr']=tmpj['IsoAbbr'].replace('.','')
-			journal[tmpj['MedAbbr']] = tmpj['MedAbbr'],tmpj['IsoAbbr'],tmpj['JournalTitle']
+			output.writerow( (tmpj['MedAbbr'],tmpj['IsoAbbr'],title_case(tmpj['JournalTitle'])) )
 			tmpj.clear()
 		tmpj[ls[0]] = ls[1].strip()
-	
-cPickle.dump(journal,sys.stdout)
+
