@@ -16,6 +16,8 @@
 # along with Bibus; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA.
 #
+from Utilities.title_case import title_case
+
 def format(s,uselocale,f=0):
 	"""Reformat Title.
 	if f=0 => This is the title
@@ -26,7 +28,7 @@ def format(s,uselocale,f=0):
 	if f == 0:
 		return s.capitalize()
 	elif f == 1:
-		return s.title()
+		return title_case(s)
 	elif f == 2:
 		return s.upper()
 	elif f == 3:
