@@ -417,7 +417,7 @@ class page_Fields(wx.Panel):
 		self.MonthEx = (u'11',self.uselocale)
 		self.TitleEx = (u'How to Marry a Millionaire',self.uselocale)
 		self.BooktitleEx = (u'How to Marry a Millionaire',self.uselocale)
-		self.JournalEx = (u'PLOS BIOL',self.uselocale)  # Must be in uppercase since we use uppercase keys for journals retrieval
+		self.JournalEx = (u'PLoS Biol',self.uselocale)
 
 	def __ExempleChoices(self,baseMod,Ex):
 		"""Return a list of exemples of formatting for modules in baseMod and with exemple Ex
