@@ -1054,6 +1054,7 @@ class mswFormatter:
 					groupInfo.append((citation.Result.Text,citation.Code.Text))
 				sortedCitationGroupInfo.append(groupInfo)
 		
+		
 		for gr in sortedCitationGroupInfo:
 			print "sortedCitationGroupInfo"
 			for ci in gr:
@@ -1113,6 +1114,8 @@ class mswFormatter:
 		citationGroupId.append(unicode(mswUtils.getXmlValueFromString("Identifier",firstField.Code.Text)))
 		for aField in mswFields:
 			#print aField.Result,aField.Result.Start,aField.Result.End
+			if not (mswUtils.isFieldCitation(aField)):
+				continue
 			curId = unicode(mswUtils.getXmlValueFromString("Identifier",aField.Code.Text))
 			prevField = aField.Previous
 			try:
@@ -1210,6 +1213,7 @@ class mswFormatter:
 		for gr in unSortedCitationGroups:
 			citeNb=0
 			for ci in gr:
+#                                print "group: ",grNb," cite: ",citeNb," data: ",sortedCitationGroupInfo[grNb][citeNb]
 				codeText = sortedCitationGroupInfo[grNb][citeNb][1]
 				ci.Code.Text = mswUtils.correctCodeTextAfterFusion(codeText,self)
 				ci.Result.Text = sortedCitationGroupInfo[grNb][citeNb][0]
