@@ -7,7 +7,7 @@
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
-#
+#/home/pmartino/Desktop/Bibus/bibus-cvs/bibus/bibOOo/bibOOoBase.py
 # bibOOo is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -319,6 +319,7 @@ class bibOOoBase(object):
 		elif order == 'index':
 			SavedState = self.tfm.IsNumberEntries
 			self.tfm.IsNumberEntries = True			# we number citations to get the order of them
+			self.model.getTextFields().refresh()
 			#
 			tmplist = [(int(x.getPresentation(False)[lbb:len(x.getPresentation(False))+lba]), x) for x in refs]
 			tmplist.sort()
@@ -343,6 +344,7 @@ class bibOOoBase(object):
 			SavedState = self.tfm.IsNumberEntries, self.tfm.IsSortByPosition
 			self.tfm.IsNumberEntries = True
 			self.tfm.IsSortByPosition = True
+			self.model.getTextFields().refresh()
 			# 3)
 			tmplist = [(int(x.getPresentation(False)[lbb:len(x.getPresentation(False))+lba]), x) for x in refs]
 			tmplist.sort()
@@ -351,10 +353,11 @@ class bibOOoBase(object):
 			for ref in refs:
 				ref.Identifier = savedIdentifiers[int(ref.Identifier)]
 			#
+			self.model.getTextFields().refresh()
 			self.tfm.IsNumberEntries, self.tfm.IsSortByPosition = SavedState
 			if order == 'document': return refs
 			if order == 'group' : return self.groupCitations(refs)					# order = 'group'
-			raise 'What are we doing here ? bibOOo line 408. order = %r is not a correct value'%order
+			raise ValueError('What are we doing here? bibOOo line 357. order = %r is not a correct value.'%order)
 # end of functions to get a sorted list of citations
 
 
