@@ -95,7 +95,7 @@ class bibOOoPlus(bibOOoBase):
 		messages is to display formatting messages
 		Default = print to stdout
 		"""
-		self.updateRef()
+		#self.updateRef()
 		if self.bibStyle['index']['IsNumberEntries']:
 			cit_sort,cit_fuse,cit_range,cit_separator,cit_rangesep = self.bibStyle['citation']['numbering']
 			cit_order,cit_asc = False,False
@@ -472,7 +472,7 @@ class bibOOoPlus(bibOOoBase):
 					reflist.sort(lambda x,y: self.cmpRefs(x.Identifier,y.Identifier,refsIndexl))	# sorting citation by index order
 					if not asc: reflist.reverse()													# we must be compatible with python2.3
 				elif how in BIB_FIELDS:
-					reflist.sort(cmp = lambda x,y: self.cmpRefsByField(x,y,how))					# sorting by field 'how' order
+					reflist.sort(lambda x,y: self.cmpRefsByField(x,y,how))					# sorting by field 'how' order
 					if not asc: reflist.reverse()
 				tmp = map(lambda x: cit[refs.index(x)], reflist)
 				#tmp.sort()
