@@ -244,6 +244,14 @@ class dbBib(object):
 		"""Return all the references tagged by user, ie all the refs except Trash"""
 		try:
 			if short:
+					# JOIN could be better for optimization but it is very slow with python-SQLite
+					# Subqueries are much faster. I will test later with new python-sqlite versions
+					#self.dbCursor.execute("""SELECT DISTINCT %s FROM %s JOIN %s AS t1 ON Id=t1.ref_Id \
+					#					JOIN %s AS t2 ON t1.key_Id=t2.key_Id \
+					#					WHERE user=%s ORDER BY %s %s"""\
+					#					%(','.join(['Id']+["%s(%s,1,%s)"%(SUBSTR,i,BIB.LIST_SHORT) for i in collist]),\
+					#					self.tableRef, self.tableLink, self.tableKey,self.param,order,how),\
+					#					(user,))
 					self.dbCursor.execute("""SELECT %s FROM %s WHERE Id IN \
 										(SELECT t1.ref_Id FROM %s AS t1 \
 										JOIN %s AS t2 ON t1.key_Id=t2.key_Id \
@@ -252,6 +260,12 @@ class dbBib(object):
 										self.tableRef, self.tableLink, self.tableKey,self.param,order,how),\
 										(user,))
 			else:
+					#self.dbCursor.execute("""SELECT DISTINCT %s FROM %s JOIN %s AS t1 ON Id=t1.ref_Id \
+					#					JOIN %s AS t2 ON t1.key_Id=t2.key_Id \
+					#					WHERE user=%s ORDER BY %s %s"""\
+					#					%(','.join(('Id',)+collist),\
+					#					self.tableRef, self.tableLink, self.tableKey,self.param,order,how),\
+					#					(user,))
 					self.dbCursor.execute("""SELECT %s FROM %s WHERE Id IN \
 										(SELECT t1.ref_Id FROM %s AS t1 \
 										JOIN %s AS t2 ON t1.key_Id=t2.key_Id \
@@ -268,6 +282,12 @@ class dbBib(object):
 		"""Return all the refs non tagged by the current user => Trash"""
 		try:
 			if short:
+					#self.dbCursor.execute("""SELECT %s FROM %s LEFT JOIN \
+					#					(SELECT ref_Id FROM %s AS t1 JOIN %s AS t2 WHERE t1.key_Id=t2.key_Id AND user=%s) t3 \
+					#					ON Id=t3.ref_Id WHERE t3.ref_Id IS NULL ORDER BY %s %s"""\
+					#					% (','.join(['Id']+["%s(%s,1,%s)"%(SUBSTR,i,BIB.LIST_SHORT) for i in collist]),\
+					#					self.tableRef, self.tableLink, self.tableKey,self.param,order,how),\
+					#					(user,))
 					self.dbCursor.execute("""SELECT %s FROM %s WHERE Id NOT IN \
 										(SELECT t1.ref_Id FROM %s AS t1 \
 										JOIN %s AS t2 ON t1.key_Id=t2.key_Id \
@@ -276,6 +296,88 @@ class dbBib(object):
 										self.tableRef, self.tableLink, self.tableKey,self.param,order,how),\
 										(user,))
 			else:
+					#self.dbCursor.execute("""SELECT %s FROM %s LEFT JOIN \
+					#					(SELECT ref_Id FROM %s AS t1 JOIN %s AS t2 WHERE t1.key_Id=t2.key_Id AND user=%s) t3 \
+					#					ON Id=t3.ref_Id WHERE t3.ref_Id IS NULL ORDER BY %s %s"""\
+					#					% (','.join(('Id',)+collist),\
+					#					self.tableRef, self.tableLink, self.tableKey,self.param,order,how),\
+					#					(user,))
+					self.dbCursor.execute("""SELECT %s FROM %s WHERE Id NOT IN \
+										(SELECT t1.ref_Id FROM %s AS t1 \
+										JOIN %s AS t2 ON t1.key_Id=t2.key_Id \
+										WHERE user=%s) ORDER BY %s %s"""\
+										%(','.join(('Id',)+collist),\
+										self.tableRef, self.tableLink, self.tableKey,self.param,order,how),\
+										(user,))
+			return self.dbCursor.fetchall()					
+		except Error,errorType:
+			self.showError("dbBibBase.getTrashRef " + `errorType.args`)
+			return None	
+	def getAllRefImport(self,collist=BIB.LIST_DISPLAY,order=BIB.LIST_ORDER,how=BIB.LIST_HOW,short=False):
+		return self.__getAllRef(BIB.TMP_IMPORT,collist,order,how,short)
+		
+	def getAllRef(self,user,collist=BIB.LIST_DISPLAY,order=BIB.LIST_ORDER,how=BIB.LIST_HOW,short=False):
+		"""Return all the references tagged by user, ie all the refs except Trash"""
+		try:
+			if short:
+					# JOIN could be better for optimization but it is very slow with python-SQLite
+					# Subqueries are much faster. I will test later with new python-sqlite versions
+					#self.dbCursor.execute("""SELECT DISTINCT %s FROM %s JOIN %s AS t1 ON Id=t1.ref_Id \
+					#					JOIN %s AS t2 ON t1.key_Id=t2.key_Id \
+					#					WHERE user=%s ORDER BY %s %s"""\
+					#					%(','.join(['Id']+["%s(%s,1,%s)"%(SUBSTR,i,BIB.LIST_SHORT) for i in collist]),\
+					#					self.tableRef, self.tableLink, self.tableKey,self.param,order,how),\
+					#					(user,))
+					self.dbCursor.execute("""SELECT %s FROM %s WHERE Id IN \
+										(SELECT t1.ref_Id FROM %s AS t1 \
+										JOIN %s AS t2 ON t1.key_Id=t2.key_Id \
+										WHERE user=%s) ORDER BY %s %s"""\
+										%(','.join(['Id']+["%s(%s,1,%s)"%(SUBSTR,i,BIB.LIST_SHORT) for i in collist]),\
+										self.tableRef, self.tableLink, self.tableKey,self.param,order,how),\
+										(user,))
+			else:
+					#self.dbCursor.execute("""SELECT DISTINCT %s FROM %s JOIN %s AS t1 ON Id=t1.ref_Id \
+					#					JOIN %s AS t2 ON t1.key_Id=t2.key_Id \
+					#					WHERE user=%s ORDER BY %s %s"""\
+					#					%(','.join(('Id',)+collist),\
+					#					self.tableRef, self.tableLink, self.tableKey,self.param,order,how),\
+					#					(user,))
+					self.dbCursor.execute("""SELECT %s FROM %s WHERE Id IN \
+										(SELECT t1.ref_Id FROM %s AS t1 \
+										JOIN %s AS t2 ON t1.key_Id=t2.key_Id \
+										WHERE user=%s) ORDER BY %s %s"""\
+										%(','.join(('Id',)+collist),\
+										self.tableRef, self.tableLink, self.tableKey,self.param,order,how),\
+										(user,))
+			return self.dbCursor.fetchall()					
+		except Error,errorType:
+			self.showError("dbBibBase.getAllRef " + `errorType.args`)
+			return None
+		
+	def getTrashRef(self,user,collist=BIB.LIST_DISPLAY,order=BIB.LIST_ORDER,how=BIB.LIST_HOW,short=False):
+		"""Return all the refs non tagged by the current user => Trash"""
+		try:
+			if short:
+					#self.dbCursor.execute("""SELECT %s FROM %s LEFT JOIN \
+					#					(SELECT ref_Id FROM %s AS t1 JOIN %s AS t2 WHERE t1.key_Id=t2.key_Id AND user=%s) t3 \
+					#					ON Id=t3.ref_Id WHERE t3.ref_Id IS NULL ORDER BY %s %s"""\
+					#					% (','.join(['Id']+["%s(%s,1,%s)"%(SUBSTR,i,BIB.LIST_SHORT) for i in collist]),\
+					#					self.tableRef, self.tableLink, self.tableKey,self.param,order,how),\
+					#					(user,))
+					self.dbCursor.execute("""SELECT %s FROM %s WHERE Id NOT IN \
+										(SELECT t1.ref_Id FROM %s AS t1 \
+										JOIN %s AS t2 ON t1.key_Id=t2.key_Id \
+										WHERE user=%s) ORDER BY %s %s"""\
+										%(','.join(['Id']+["%s(%s,1,%s)"%(SUBSTR,i,BIB.LIST_SHORT) for i in collist]),\
+										self.tableRef, self.tableLink, self.tableKey,self.param,order,how),\
+										(user,))
+			else:
+					#self.dbCursor.execute("""SELECT %s FROM %s LEFT JOIN \
+					#					(SELECT ref_Id FROM %s AS t1 JOIN %s AS t2 WHERE t1.key_Id=t2.key_Id AND user=%s) t3 \
+					#					ON Id=t3.ref_Id WHERE t3.ref_Id IS NULL ORDER BY %s %s"""\
+					#					% (','.join(('Id',)+collist),\
+					#					self.tableRef, self.tableLink, self.tableKey,self.param,order,how),\
+					#					(user,))
 					self.dbCursor.execute("""SELECT %s FROM %s WHERE Id NOT IN \
 										(SELECT t1.ref_Id FROM %s AS t1 \
 										JOIN %s AS t2 ON t1.key_Id=t2.key_Id \
@@ -385,7 +487,13 @@ class dbBib(object):
 	def getAllRefSearch(self,user,searchStr,collist=BIB.LIST_DISPLAY,order=BIB.LIST_ORDER,how=BIB.LIST_HOW,short=False):
 		"""Return the references corresponding to the search 'searchStr' from all the refs belonging to current user"""
 		try:
+			#print searchStr.encode('latin1')
 			if not short:
+				#tmpstr = """SELECT DISTINCT %s FROM %s JOIN %s AS t1 ON Id=t1.ref_Id \
+				#			JOIN %s AS t2 ON t1.key_Id=t2.key_Id \
+				#			WHERE user="%s" AND %s ORDER BY %s %s"""\
+				#			%(','.join(('Id',)+ collist),\
+				#			self.tableRef, self.tableLink, self.tableKey,user,searchStr,order,how)
 				tmpstr = """SELECT %s FROM %s WHERE Id IN \
 							(SELECT t1.ref_Id FROM %s AS t1 \
 							JOIN %s AS t2 ON t1.key_Id=t2.key_Id \
@@ -393,6 +501,11 @@ class dbBib(object):
 							%(','.join(('Id',)+ collist),\
 							self.tableRef, self.tableLink, self.tableKey,user,searchStr,order,how)
 			else:
+				#tmpstr = """SELECT DISTINCT %s FROM %s JOIN %s AS t1 ON Id=t1.ref_Id \
+				#			JOIN %s AS t2 ON t1.key_Id=t2.key_Id \
+				#			WHERE user="%s" AND %s ORDER BY %s %s"""\
+				#			%(','.join(['Id']+["%s(%s,1,%s)"%(SUBSTR,i,BIB.LIST_SHORT) for i in collist]),\
+				#			self.tableRef, self.tableLink, self.tableKey,user,searchStr,order,how)
 				tmpstr = """SELECT %s FROM %s WHERE Id IN \
 							(SELECT t1.ref_Id FROM %s AS t1 \
 							JOIN %s AS t2 ON t1.key_Id=t2.key_Id \
@@ -404,30 +517,6 @@ class dbBib(object):
 		except Error,errorType:
 			self.showError("dbBibBase.getAllRefSearch: " + `errorType.args`)
 			return None
-			
-	def getTrashRefSearch(self,user,searchStr,collist=BIB.LIST_DISPLAY,order=BIB.LIST_ORDER,how=BIB.LIST_HOW,short=False):
-		"""Return the references corresponding to the search 'searchStr' from all the refs in the Trash of current user"""
-		try:
-			if short:
-					tmpstr = """SELECT %s FROM %s WHERE Id NOT IN \
-										(SELECT t1.ref_Id FROM %s AS t1 \
-										JOIN %s AS t2 ON t1.key_Id=t2.key_Id \
-										WHERE user="%s") AND %s ORDER BY %s %s"""\
-										%(','.join(['Id']+["%s(%s,1,%s)"%(SUBSTR,i,BIB.LIST_SHORT)\
-										    for i in collist]),\
-										self.tableRef, self.tableLink, self.tableKey,user,searchStr,order,how)
-			else:
-					tmpstr = """SELECT %s FROM %s WHERE Id NOT IN \
-										(SELECT t1.ref_Id FROM %s AS t1 \
-										JOIN %s AS t2 ON t1.key_Id=t2.key_Id \
-										WHERE user="%s") AND %s ORDER BY %s %s"""\
-										%(','.join(('Id',)+collist),\
-										self.tableRef, self.tableLink, self.tableKey,user,searchStr,order,how)
-			self.dbCursor.execute(tmpstr.encode(BIB.ENCODING,BIB.ENC_ERRORS))
-			return self.dbCursor.fetchall()
-		except Error,errorType:
-			self.showError("dbBibBase.getTrashRefSearch: " + `errorType.args`)
-			return None
 
 	def getRefFromIdentifiers(self,Identifiers,collist=BIB.LIST_DISPLAY,order=BIB.LIST_ORDER,how=BIB.LIST_HOW):
 		"""Return the references corresponding to the list of Identifiers"""
